.. _intro-install:

==================
Installation guide
==================

.. _faq-python-versions:

Supported Python versions
=========================

GlassPy requires Python 3.9+.


.. _faq-install:

Installing GlassPy
==================

Binary installers for the latest released version are available from the `Python
Package Index`_. To install GlassPy and all its necessary dependencies, use
pip run::

    pip install glasspy

.. _Python Package Index: https://pypi.org/project/glasspy/
